import * as ecr from "../../aws-ecr";
import { Construct } from 'constructs';
import "../../assets";
/**
 * (experimental) Options for TarballImageAsset.
 *
 * @experimental
 */
export interface TarballImageAssetProps {
    /**
     * (experimental) Path to the tarball.
     *
     * @experimental
     */
    readonly tarballFile: string;
}
/**
 * (experimental) An asset that represents a Docker image.
 *
 * The image will loaded from an existing tarball and uploaded to an ECR repository.
 *
 * @experimental
 */
export declare class TarballImageAsset extends Construct {
    /**
     * (experimental) The full URI of the image (including a tag).
     *
     * Use this reference to pull
     * the asset.
     *
     * @experimental
     */
    imageUri: string;
    /**
     * (experimental) Repository where the image is stored.
     *
     * @experimental
     */
    repository: ecr.IRepository;
    /**
     * (experimental) A hash of this asset, which is available at construction time.
     *
     * As this is a plain string, it
     * can be used in construct IDs in order to enforce creation of a new resource when the content
     * hash has changed.
     *
     * @experimental
     */
    readonly assetHash: string;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: TarballImageAssetProps);
}
